@@ -6,4 +6,9 @@ import scSpatial.widgets
 import scSpatial.analysis
 import scSpatial.app
 
-VERSION = "0.1.0"
+VERSION = "0.1.2"
+
+
+def run():
+    "Entry point for CLI"
+    app = scSpatial.app.App()
\ No newline at end of file
