@@ -29,12 +29,4 @@ class App:
         )
 
         self.viewer.show()
-        napari.run()
-
-
-app = App()
-
-
-def run():
-    "Entry point for CLI"
-    app = App()
\ No newline at end of file
+        napari.run()
\ No newline at end of file
